import {
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  line,
} from 'd3';

export const viz = (
  selection,
  { data, width, height, margin, xValue, yValue, y2Value }
) => {
  const { top, right, bottom, left } = margin;

  const x = scaleLinear()
    .domain(extent(data, xValue))
    .range([left, width - right]);

  const y = scaleLinear()
    .domain(extent(data, yValue))
    .range([height - bottom, top]);

  selection
    .selectAll('.line')
    .data([null])
    .join('path')
    .attr('class', 'line')
    .attr(
      'd',
      line()
        .x((d) => x(xValue(d)))
        .y((d) => y(yValue(d)))(data)
    );

  selection
    .selectAll('.line-2')
    .data([null])
    .join('path')
    .attr('class', 'line-2')
    .attr(
      'd',
      line()
        .x((d) => x(xValue(d)))
        .y((d) => y(y2Value(d)))(data)
    )
    .attr('class', 'line-2');

  selection
    .selectAll('.y-axis')
    .data([null])
    .join('g')
    .attr('class', 'y-axis')
    .attr('transform', `translate(${left},0)`)
    .call(
      axisLeft(y)
        .tickSize(-(width - left - right))
        .tickPadding(10)
    )
    .selectAll('.domain')
    .remove();

  selection
    .selectAll('.x-axis')
    .data([null])
    .join('g')
    .attr('class', 'x-axis')
    .attr('transform', `translate(0,${height - bottom})`)
    .call(
      axisBottom(x)
        .tickSize(-(height - top - bottom))
        .tickFormat((d) => d)
        .tickPadding(12)
    )
    .selectAll('.domain')
    .remove();
};
